PRO BEACON_DRIVER,INFILENAME, OUTFILE
;+
; Project     :	STEREO - IMPACT, LET
;
; Name        : BEACON_DRIVER
;
; Purpose     :	Test program to feed IMPACT beacon packets to SEP Beacon processing routines
;
; Category    :	STEREO, IMPACT, SEP
;
; Explanation :	reads STEREO telemetry data and passes
;               IMPACT beacon packets (apid=624) to SEP Beacon processing.
;               Also, calls sep_beacon_common to setup SEP beacon common block
;
; Syntax      :	
;
; Examples    :	
;
; Inputs      :	Filename of telemetry data file (PTP or STP).
;
; Opt. Inputs :	None.
;
; Outputs     :	None
;
; Opt. Outputs:	None.
;
; Keywords    :	None
;
; Calls       :	sep_beacon_common, read_stereo_pkt, parse_stereo_pkt, sep_beacon
;
; Common      :
;
; Restrictions:	
;
; Side effects:	None.
;
; Prev. Hist. :	None.
;
; History     :	Version 1 (preliminary), 26-Sep-2005, Andrew Davis, Caltech
;
; Contact     :	ad@srl.caltech.edu
;-
;

  sep_beacon_common ; setup SEP beacon global vars, is there a better way?

  ; Open input data file for reading.
  ; printf,-2,'Opening input file'

  openr, unit, infilename, /get_lun, error = error_flag
  IF (error_flag ne 0) then BEGIN
      printf, -2, !err_string
      exit, /NO_CONFIRM, STATUS=-1
  ENDIF 

   ; open the output file for appending - the header has already been written to the file
   openw, olun, OUTFILE, /append, /get_lun, error = error_flag
   if (error_flag ne 0)then begin
      printf, -2, !err_string
      exit, /NO_CONFIRM, STATUS=-1
   endif

  ; read in the 32-byte header at the start of each LET MSU accelerator
  ; calibration telemetry data file. Apart from this header, the file
  ; is in Payload telem pkt format.
  ; MSU_header=BYTARR(32)
  ; readu,unit,MSU_header

  packet = 0
  sepbeacondata = 0

  WHILE 1 DO BEGIN
     read_stereo_pkt, unit, packet
     if n_elements(packet) eq 0 then break
     apid = parse_stereo_pkt(packet, /APID )

     ; send IMPACT beacon packets (apid=624) to SEP beacon processing.
     ; sepbeacondata structure is returned undefined if there
     ; was an error processing a packet
     IF apid eq 624 THEN BEGIN
        sep_beacon, packet, sepbeacondata, flag
;	print, "status= ", flag

	; do something useful with the SEP beacon data structure here
	IF n_elements(sepbeacondata) ne 0 THEN BEGIN
	   utc = int2utc(sepbeacondata.header.timeCDS)
           year = utc.year
	   doy = utc2doy( utc, /FRACTIONAL)
           hour = utc.hour
           min = utc.minute
           sec = utc.second
;           printf, olun, year, doy, hour, min, sec, $
;		sepbeacondata.status.LETLivetime, sepbeacondata.status.HETLivetime, $
;		sepbeacondata.status.LETDyThState, sepbeacondata.status.HETmode, $
;		sepbeacondata.status.HETStatus, sepbeacondata.status.HETStopEffic, sepbeacondata.status.HETPenEffic, $
;		ishft(sepbeacondata.status.SEPTStatus,-20), $
;		sepbeacondata.SUMMARYflux, sepbeacondata.SUMMARYcounts, $
;               FORMAT='(I4,1X,F10.6,3(1X,I2),1X,F7.4,1X,F7.4,1X,I1,1X,I1,1X,I8,1X,I8,1X,I8,1X,I4,1X,7(1X,E11.4),7(1X,I8))'
           printf, olun, year, doy, hour, min, sec, $
		sepbeacondata.status.LETLivetime, sepbeacondata.status.HETLivetime, $
		sepbeacondata.status.LETDyThState, sepbeacondata.status.HETmode, $
		sepbeacondata.status.SEPTStatus, $
		sepbeacondata.SUMMARYflux, sepbeacondata.SUMMARYcounts, $
                FORMAT='(I4,1X,F10.6,3(1X,I2),1X,F7.4,1X,F7.4,1X,I1,1X,I1,1X,I4,1X,12(1X,E11.4),12(1X,I11))'

	ENDIF
     ENDIF
  ENDWHILE
  
  free_lun, unit, olun
  
end ; beacon_driver
