PRO IMPACT_BEACON, PACKET, FILENAME
;+
; Project     :	STEREO - IMPACT
;
; Name        : IMPACT_BEACON
;
; Purpose     :	Convert raw IMPACT Beacon data into physical units
;
; Category    :	STEREO, IMPACT
;
; Explanation :	
;
; Syntax      :	IMPACT_BEACON, PACKET, FILENAME
;
; Examples    :	
;
; Inputs      :	PACKET - an IMPACT Beacon packet to be processed
;               FILENAME - the name of a CDF file for output
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	None
;
; Calls       :	None
;
; Common      : None
;
; Restrictions:	
;
; Side effects:	None.
;
; Prev. Hist. :	None.
;
; History     :	Version 1 (preliminary), 10-Nov-2005, Peter Schroeder,
;                  UC-Berkeley.
;
; Contact     :	peters@ssl.berkeley.edu
;-
;

if parse_stereo_pkt(packet,/apid) ne '270'XU then return

if (packet.grh.spacecraft_id eq 'EA'XU) then begin
   SOURCE_FILE = 'impacta_beacon_skt.cdf'
   SC_STRING = 'STA'
endif else begin
   SOURCE_FILE = 'impactb_beacon_skt.cdf'
   SC_STRING = 'STB'
endelse

SOURCE_FILE = concat_dir('$IMPACT_CALIB_DATA', SOURCE_FILE)

filematch = file_search(filename, count = filecount)
if filecount eq 0 then file_copy, SOURCE_FILE, filename

mag_data = mag_xform_packet(packet)
sweaste_data = sweaste_beacon(packet)
sep_beacon, packet, sep_data, sep_flag
if sep_flag eq 0 then return

ISCStatus = packet.dat[2]
InterfaceActive = packet.dat[1]
SWEAModeID = packet.dat[4]
STEModeID = packet.dat[3]

utcpkttim = parse_stereo_pkt(packet,/pkt_date)
utcsec = utc2sec(utcpkttim)
utcpkktim = sec2utc(utcsec + double(packet.dat[0])/65536d)
utc = anytim2utc(utcpkttim,/external)

cdf_epoch, pktepoch, utc.year, utc.month, utc.day, utc.hour, utc.minute, $
   utc.second, utc.millisecond,/compute_epoch

utcsec = utc2sec(utcpkttim)
utcsec = utcsec + 5d
utc = sec2utc(utcsec)
thismag = double([mag_data.MAGX_01, mag_data.MAGY_01, mag_data.MAGZ_01])
thiscmat = get_stereo_cmat(utc, SC_STRING, system = 'HGRTN')
mag0 = transpose(thiscmat) # thismag
utc = anytim2utc(utc,/external)

cdf_epoch, mag0epoch, utc.year, utc.month, utc.day, utc.hour, utc.minute, $
   utc.second, utc.millisecond,/compute_epoch

utcsec = utc2sec(utcpkttim)
utcsec = utcsec + 15d
utc = sec2utc(utcsec)
thismag = double([mag_data.MAGX_02, mag_data.MAGY_02, mag_data.MAGZ_02])
thiscmat = get_stereo_cmat(utc, SC_STRING, system = 'HGRTN')
mag1 = transpose(thiscmat) # thismag
utc = anytim2utc(utc,/external)

cdf_epoch, mag1epoch, utc.year, utc.month, utc.day, utc.hour, utc.minute, $
   utc.second, utc.millisecond,/compute_epoch

utcsec = utc2sec(utcpkttim)
utcsec = utcsec + 25d
utc = sec2utc(utcsec)
thismag = double([mag_data.MAGX_03, mag_data.MAGY_03, mag_data.MAGZ_03])
thiscmat = get_stereo_cmat(utc, SC_STRING, system = 'HGRTN')
mag2 = transpose(thiscmat) # thismag
utc = anytim2utc(utc,/external)

cdf_epoch, mag2epoch, utc.year, utc.month, utc.day, utc.hour, utc.minute, $
   utc.second, utc.millisecond,/compute_epoch

utcsec = utc2sec(utcpkttim)
utcsec = utcsec + 35d
utc = sec2utc(utcsec)
thismag = double([mag_data.MAGX_04, mag_data.MAGY_04, mag_data.MAGZ_04])
thiscmat = get_stereo_cmat(utc, SC_STRING, system = 'HGRTN')
mag3 = transpose(thiscmat) # thismag
utc = anytim2utc(utc,/external)

cdf_epoch, mag3epoch, utc.year, utc.month, utc.day, utc.hour, utc.minute, $
   utc.second, utc.millisecond,/compute_epoch

utcsec = utc2sec(utcpkttim)
utcsec = utcsec + 45d
utc = sec2utc(utcsec)
thismag = double([mag_data.MAGX_05, mag_data.MAGY_05, mag_data.MAGZ_05])
thiscmat = get_stereo_cmat(utc, SC_STRING, system = 'HGRTN')
mag4 = transpose(thiscmat) # thismag
utc = anytim2utc(utc,/external)

cdf_epoch, mag4epoch, utc.year, utc.month, utc.day, utc.hour, utc.minute, $
   utc.second, utc.millisecond,/compute_epoch

utcsec = utc2sec(utcpkttim)
utcsec = utcsec + 55d
utc = sec2utc(utcsec)
thismag = double([mag_data.MAGX_06, mag_data.MAGY_06, mag_data.MAGZ_06])
thiscmat = get_stereo_cmat(utc, SC_STRING, system = 'HGRTN')
mag5 = transpose(thiscmat) # thismag
utc = anytim2utc(utc,/external)

cdf_epoch, mag5epoch, utc.year, utc.month, utc.day, utc.hour, utc.minute, $
   utc.second, utc.millisecond,/compute_epoch

utcsec = utc2sec(utcpkttim)
utcsec = utcsec + 61d
utc = sec2utc(utcsec)
utc = anytim2utc(utc,/external)

cdf_epoch, sweaepoch, utc.year, utc.month, utc.day, utc.hour, utc.minute, $
   utc.second, utc.millisecond,/compute_epoch

utc = anytim2utc(sep_data.header.timeCDS,/external)

cdf_epoch, sepepoch, utc.year, utc.month, utc.day, utc.hour, utc.minute, $
   utc.second, utc.millisecond,/compute_epoch

cdfid = cdf_open(filename)
if filecount eq 0 then recstart = 0 else begin
   quiet=!quiet  &  !quiet=1 
   cdf_control, cdfid, get_var_info=info, variable='Epoch'
   !quiet=quiet
   recstart = info.maxrec+1
endelse

cdf_varput, cdfid, 'Epoch', pktepoch, rec_start = recstart
cdf_varput, cdfid, 'ISCStatus', ISCStatus, rec_start = recstart
cdf_varput, cdfid, 'InterfaceActive', InterfaceActive, rec_start = recstart
cdf_varput, cdfid, 'SWEAModeID', SWEAModeID, rec_start = recstart
cdf_varput, cdfid, 'STEModeID', STEModeID, rec_start = recstart

cdf_varput, cdfid, 'Epoch_SWEA', sweaepoch, rec_start = recstart
cdf_varput, cdfid, 'Nelectrons', sweaste_data.SWEA_N, rec_start = recstart
cdf_varput, cdfid, 'Ve', sweaste_data.SWEA_V, rec_start = recstart
cdf_varput, cdfid, 'Pe', sweaste_data.SWEA_P, rec_start = recstart
cdf_varput, cdfid, 'He', sweaste_data.SWEA_NH, rec_start = recstart
cdf_varput, cdfid, 'V0', sweaste_data.SWEA_V0, rec_start = recstart
cdf_varput, cdfid, 'MagAz', sweaste_data.SWEA_MagAz, rec_start = recstart
cdf_varput, cdfid, 'MagEl', sweaste_data.SWEA_MagEl, rec_start = recstart
cdf_varput, cdfid, 'SWEAPAD', reform(double(sweaste_data.SWEA_PAD),2,6,2), $
   rec_start = recstart
cdf_varput, cdfid, 'SWEAPAD_Energy', [sweaste_data.SWEA_PAD_E0, $
   sweaste_data.SWEA_PAD_E1], rec_start = recstart
cdf_varput, cdfid, 'STEUns', double(sweaste_data.STE_Uns), rec_start = recstart
cdf_varput, cdfid, 'STEUs', double(sweaste_data.STE_Us), rec_start = recstart
cdf_varput, cdfid, 'STED', double(sweaste_data.STE_D), rec_start = recstart

cdf_varput, cdfid, 'Epoch_SEP', sepepoch, rec_start = recstart
cdf_varput, cdfid, 'SEP_SW_Version', sep_data.header.SWversion, rec_start = recstart
cdf_varput, cdfid, 'HETLiveTime', sep_data.status.HETLiveTime, rec_start = recstart
cdf_varput, cdfid, 'HETMode', sep_data.status.HETmode, rec_start = recstart
cdf_varput, cdfid, 'LETLiveTime', sep_data.status.LETLiveTime, rec_start = recstart
cdf_varput, cdfid, 'LETTrigRate', sep_data.status.LETTrigCnts, rec_start = recstart
cdf_varput, cdfid, 'LETHazRate', sep_data.status.LETHazCnts, rec_start = recstart
cdf_varput, cdfid, 'LETAcceptRate', sep_data.status.LETAcceptCnts, rec_start = recstart
cdf_varput, cdfid, 'LETCodeOK', sep_data.status.LETCodeOK, rec_start = recstart
cdf_varput, cdfid, 'LETHeaterDutyCycle', sep_data.status.LETHeaterDutyCycle, rec_start = recstart
cdf_varput, cdfid, 'LETLeakConv', sep_data.status.LETLeakConv, rec_start = recstart
cdf_varput, cdfid, 'LETDyThState', sep_data.status.LETDyThState, rec_start = recstart
cdf_varput, cdfid, 'LETMinute', sep_data.status.LETMinute, rec_start = recstart
cdf_varput, cdfid, 'SEPTStatus', sep_data.status.SEPTStatus, rec_start = recstart

cdf_varput, cdfid, 'HETElectronFlux', sep_data.HETflux.Electrons, rec_start = recstart
cdf_varput, cdfid, 'HETProtonFlux', [sep_data.HETflux.Protons1, $
   sep_data.HETflux.Protons2, sep_data.HETflux.Protons3], rec_start = recstart
cdf_varput, cdfid, 'HETHeFlux', [sep_data.HETflux.He1, $
   sep_data.HETflux.He2, sep_data.HETflux.He3], rec_start = recstart
cdf_varput, cdfid, 'HETCNOFlux', [sep_data.HETflux.CNO1, $
   sep_data.HETflux.CNO2], rec_start = recstart
cdf_varput, cdfid, 'HETFeFlux', sep_data.HETflux.Fe, rec_start = recstart

cdf_varput, cdfid, 'SITHeFlux', [sep_data.SITflux.He1, sep_data.SITflux.He2, $
   sep_data.SITflux.He3, sep_data.SITflux.He4], rec_start = recstart
cdf_varput, cdfid, 'SITCNOFlux', [sep_data.SITflux.CNO1, $
   sep_data.SITflux.CNO2, sep_data.SITflux.CNO3, sep_data.SITflux.CNO4], rec_start = recstart
cdf_varput, cdfid, 'SITFeFlux', [sep_data.SITflux.Fe1, sep_data.SITflux.Fe2, $
   sep_data.SITflux.Fe3, sep_data.SITflux.Fe4], rec_start = recstart

cdf_varput, cdfid, 'LETProtonFlux', [sep_data.LETflux.Protons1, $
   sep_data.LETflux.Protons2A, sep_data.LETflux.Protons2B, $
   sep_data.LETflux.Protons3], rec_start = recstart
cdf_varput, cdfid, 'LET4HeFlux', [sep_data.LETflux.He4_1, $
   sep_data.LETflux.He4_2A, sep_data.LETflux.He4_2B, sep_data.LETflux.He4_3A, $
   sep_data.LETflux.He4_3B], rec_start = recstart
cdf_varput, cdfid, 'LET3HeFlux', [sep_data.LETflux.He3_1, $
   sep_data.LETflux.He3_2], rec_start = recstart
cdf_varput, cdfid, 'LETCNOFlux', [sep_data.LETflux.CNO1, $
   sep_data.LETflux.CNO2, sep_data.LETflux.CNO3], rec_start = recstart
cdf_varput, cdfid, 'LETFeFlux', [sep_data.LETflux.Fe1, sep_data.LETflux.Fe2, $
   sep_data.LETflux.Fe3, sep_data.LETflux.Fe4], rec_start = recstart

cdf_varput, cdfid, 'SEPTElectronFlux', [sep_data.SEPTflux.Electrons0N_1, $
   sep_data.SEPTflux.Electrons2N_1, sep_data.SEPTflux.Electrons0E_1, $
   sep_data.SEPTflux.Electrons2E_1, sep_data.SEPTflux.ElectronsSum_2, $
   sep_data.SEPTflux.ElectronsSum_3, sep_data.SEPTflux.Electrons0N_4, $
   sep_data.SEPTflux.Electrons2N_4, sep_data.SEPTflux.Electrons0E_4, $
   sep_data.SEPTflux.Electrons2E_4], rec_start = recstart
cdf_varput, cdfid, 'SEPTIonFlux', [sep_data.SEPTflux.Ions1N_1, $
   sep_data.SEPTflux.Ions3N_1, sep_data.SEPTflux.Ions1E_1, $
   sep_data.SEPTflux.Ions3E_1, sep_data.SEPTflux.IonsSum_2, $
   sep_data.SEPTflux.IonsSum_3, sep_data.SEPTflux.Ions1N_4, $
   sep_data.SEPTflux.Ions3N_4, sep_data.SEPTflux.Ions1E_4, $
   sep_data.SEPTflux.Ions3E_4], rec_start = recstart

cdf_varput, cdfid, 'HETElectronCnts', sep_data.HETcounts.Electrons, rec_start = recstart
cdf_varput, cdfid, 'HETProtonCnts', [sep_data.HETcounts.Protons1, $
   sep_data.HETcounts.Protons2, sep_data.HETcounts.Protons3], rec_start = recstart
cdf_varput, cdfid, 'HETHeCnts', [sep_data.HETcounts.He1, $
   sep_data.HETcounts.He2, sep_data.HETcounts.He3], rec_start = recstart
cdf_varput, cdfid, 'HETCNOCnts', [sep_data.HETcounts.CNO1, $
   sep_data.HETcounts.CNO2], rec_start = recstart
cdf_varput, cdfid, 'HETFeCnts', sep_data.HETcounts.Fe, rec_start = recstart

cdf_varput, cdfid, 'SITHeCnts', [sep_data.SITcounts.He1, sep_data.SITcounts.He2, $
   sep_data.SITcounts.He3, sep_data.SITcounts.He4], rec_start = recstart
cdf_varput, cdfid, 'SITCNOCnts', [sep_data.SITcounts.CNO1, $
   sep_data.SITcounts.CNO2, sep_data.SITcounts.CNO3, sep_data.SITcounts.CNO4], rec_start = recstart
cdf_varput, cdfid, 'SITFeCnts', [sep_data.SITcounts.Fe1, sep_data.SITcounts.Fe2, $
   sep_data.SITcounts.Fe3, sep_data.SITcounts.Fe4], rec_start = recstart

cdf_varput, cdfid, 'LETProtonCnts', [sep_data.LETcounts.Protons1, $
   sep_data.LETcounts.Protons2A, sep_data.LETcounts.Protons2B, $
   sep_data.LETcounts.Protons3], rec_start = recstart
cdf_varput, cdfid, 'LET4HeCnts', [sep_data.LETcounts.He4_1, $
   sep_data.LETcounts.He4_2A, sep_data.LETcounts.He4_2B, sep_data.LETcounts.He4_3A, $
   sep_data.LETcounts.He4_3B], rec_start = recstart
cdf_varput, cdfid, 'LET3HeCnts', [sep_data.LETcounts.He3_1, $
   sep_data.LETcounts.He3_2], rec_start = recstart
cdf_varput, cdfid, 'LETCNOCnts', [sep_data.LETcounts.CNO1, $
   sep_data.LETcounts.CNO2, sep_data.LETcounts.CNO3], rec_start = recstart
cdf_varput, cdfid, 'LETFeCnts', [sep_data.LETcounts.Fe1, sep_data.LETcounts.Fe2, $
   sep_data.LETcounts.Fe3, sep_data.LETcounts.Fe4], rec_start = recstart

cdf_varput, cdfid, 'SEPTElectronCnts', [sep_data.SEPTcounts.Electrons0N_1, $
   sep_data.SEPTcounts.Electrons2N_1, sep_data.SEPTcounts.Electrons0E_1, $
   sep_data.SEPTcounts.Electrons2E_1, sep_data.SEPTcounts.ElectronsSum_2, $
   sep_data.SEPTcounts.ElectronsSum_3, sep_data.SEPTcounts.Electrons0N_4, $
   sep_data.SEPTcounts.Electrons2N_4, sep_data.SEPTcounts.Electrons0E_4, $
   sep_data.SEPTcounts.Electrons2E_4], rec_start = recstart
cdf_varput, cdfid, 'SEPTIonCnts', [sep_data.SEPTcounts.Ions1N_1, $
   sep_data.SEPTcounts.Ions3N_1, sep_data.SEPTcounts.Ions1E_1, $
   sep_data.SEPTcounts.Ions3E_1, sep_data.SEPTcounts.IonsSum_2, $
   sep_data.SEPTcounts.IonsSum_3, sep_data.SEPTcounts.Ions1N_4, $
   sep_data.SEPTcounts.Ions3N_4, sep_data.SEPTcounts.Ions1E_4, $
   sep_data.SEPTcounts.Ions3E_4], rec_start = recstart

cdf_varput, cdfid, 'SFSEPTElectrons', sep_data.SUMMARYflux.SEPT_E, $
   rec_start = recstart
cdf_varput, cdfid, 'SFHETElectrons', sep_data.SUMMARYflux.HET_E, $
   rec_start = recstart
cdf_varput, cdfid, 'SFSEPTIons1', sep_data.SUMMARYflux.SEPT_H_1, $
   rec_start = recstart
cdf_varput, cdfid, 'SFSEPTIons2', sep_data.SUMMARYflux.SEPT_H_2, $
   rec_start = recstart
cdf_varput, cdfid, 'SFLETProtons', sep_data.SUMMARYflux.LET_H, $
   rec_start = recstart
cdf_varput, cdfid, 'SFHETProtons', sep_data.SUMMARYflux.HET_H, $
   rec_start = recstart
cdf_varput, cdfid, 'SFSITHe', sep_data.SUMMARYflux.SIT_He, $
   rec_start = recstart
cdf_varput, cdfid, 'SFSITCNO', sep_data.SUMMARYflux.SIT_CNO, $
   rec_start = recstart
cdf_varput, cdfid, 'SFSITFe', sep_data.SUMMARYflux.SIT_Fe, $
   rec_start = recstart
cdf_varput, cdfid, 'SFLETHe', sep_data.SUMMARYflux.LET_He, $
   rec_start = recstart
cdf_varput, cdfid, 'SFLETCNO', sep_data.SUMMARYflux.LET_CNO, $
   rec_start = recstart
cdf_varput, cdfid, 'SFLETFe', sep_data.SUMMARYflux.LET_Fe, $
   rec_start = recstart
   
cdf_varput, cdfid, 'SCSEPTElectrons', sep_data.SUMMARYcounts.SEPT_E, $
   rec_start = recstart
cdf_varput, cdfid, 'SCHETElectrons', sep_data.SUMMARYcounts.HET_E, $
   rec_start = recstart
cdf_varput, cdfid, 'SCSEPTIons1', sep_data.SUMMARYcounts.SEPT_H_1, $
   rec_start = recstart
cdf_varput, cdfid, 'SCSEPTIons2', sep_data.SUMMARYcounts.SEPT_H_2, $
   rec_start = recstart
cdf_varput, cdfid, 'SCLETProtons', sep_data.SUMMARYcounts.LET_H, $
   rec_start = recstart
cdf_varput, cdfid, 'SCHETProtons', sep_data.SUMMARYcounts.HET_H, $
   rec_start = recstart
cdf_varput, cdfid, 'SCSITHe', sep_data.SUMMARYcounts.SIT_He, $
   rec_start = recstart
cdf_varput, cdfid, 'SCSITCNO', sep_data.SUMMARYcounts.SIT_CNO, $
   rec_start = recstart
cdf_varput, cdfid, 'SCSITFe', sep_data.SUMMARYcounts.SIT_Fe, $
   rec_start = recstart
cdf_varput, cdfid, 'SCLETHe', sep_data.SUMMARYcounts.LET_He, $
   rec_start = recstart
cdf_varput, cdfid, 'SCLETCNO', sep_data.SUMMARYcounts.LET_CNO, $
   rec_start = recstart
cdf_varput, cdfid, 'SCLETFe', sep_data.SUMMARYcounts.LET_Fe, $
   rec_start = recstart

cdf_varput, cdfid, 'MAGHKP', mag_data.imaghkp, rec_start = recstart
cdf_varput, cdfid, 'Epoch_MAG', mag0epoch, rec_start = recstart*6
cdf_varput, cdfid, 'MAGBField', mag0, rec_start = recstart*6
cdf_varput, cdfid, 'Epoch_MAG', mag1epoch, rec_start = recstart*6+1
cdf_varput, cdfid, 'MAGBField', mag1, rec_start = recstart*6+1
cdf_varput, cdfid, 'Epoch_MAG', mag2epoch, rec_start = recstart*6+2
cdf_varput, cdfid, 'MAGBField', mag2, rec_start = recstart*6+2
cdf_varput, cdfid, 'Epoch_MAG', mag3epoch, rec_start = recstart*6+3
cdf_varput, cdfid, 'MAGBField', mag3, rec_start = recstart*6+3
cdf_varput, cdfid, 'Epoch_MAG', mag4epoch, rec_start = recstart*6+4
cdf_varput, cdfid, 'MAGBField', mag4, rec_start = recstart*6+4
cdf_varput, cdfid, 'Epoch_MAG', mag5epoch, rec_start = recstart*6+5
cdf_varput, cdfid, 'MAGBField', mag5, rec_start = recstart*6+5

cdf_close, cdfid

return
end
